Performance
==================================================================================

DaCy is evaulate contains performance metrics for 

.. toctree::
  :maxdepth: 3

  performance.general
  performance.robustness